/********************************************************************************
** Form generated from reading UI file 'instanceselector.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INSTANCESELECTOR_H
#define UI_INSTANCESELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_InstanceSelector
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QListView *listView;

    void setupUi(QWidget *InstanceSelector)
    {
        if (InstanceSelector->objectName().isEmpty())
            InstanceSelector->setObjectName("InstanceSelector");
        InstanceSelector->resize(400, 300);
        verticalLayout = new QVBoxLayout(InstanceSelector);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(InstanceSelector);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        listView = new QListView(InstanceSelector);
        listView->setObjectName("listView");
        listView->setEditTriggers(QAbstractItemView::NoEditTriggers);

        verticalLayout->addWidget(listView);


        retranslateUi(InstanceSelector);

        QMetaObject::connectSlotsByName(InstanceSelector);
    } // setupUi

    void retranslateUi(QWidget *InstanceSelector)
    {
        label->setText(QCoreApplication::translate("InstanceSelector", "There are multiple instances of Akonadi running in the current D-Bus session. Please select the instance you want to connect to.", nullptr));
        (void)InstanceSelector;
    } // retranslateUi

};

namespace Ui {
    class InstanceSelector: public Ui_InstanceSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INSTANCESELECTOR_H
