/********************************************************************************
** Form generated from reading UI file 'dbconsoletab.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DBCONSOLETAB_H
#define UI_DBCONSOLETAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DbConsoleTab
{
public:
    QVBoxLayout *verticalLayout_2;
    QSplitter *splitter;
    QStackedWidget *resultStack;
    QWidget *resultViewPage;
    QVBoxLayout *verticalLayout;
    QTableView *resultView;
    QWidget *errorViewPage;
    QVBoxLayout *verticalLayout_3;
    QPlainTextEdit *errorView;
    QWidget *layoutWidget;
    QHBoxLayout *horizontalLayout;
    QPlainTextEdit *queryEdit;
    QPushButton *execButton;

    void setupUi(QWidget *DbConsoleTab)
    {
        if (DbConsoleTab->objectName().isEmpty())
            DbConsoleTab->setObjectName("DbConsoleTab");
        DbConsoleTab->resize(400, 443);
        verticalLayout_2 = new QVBoxLayout(DbConsoleTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        splitter = new QSplitter(DbConsoleTab);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        splitter->setChildrenCollapsible(false);
        resultStack = new QStackedWidget(splitter);
        resultStack->setObjectName("resultStack");
        resultViewPage = new QWidget();
        resultViewPage->setObjectName("resultViewPage");
        verticalLayout = new QVBoxLayout(resultViewPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        resultView = new QTableView(resultViewPage);
        resultView->setObjectName("resultView");
        resultView->setContextMenuPolicy(Qt::ActionsContextMenu);

        verticalLayout->addWidget(resultView);

        resultStack->addWidget(resultViewPage);
        errorViewPage = new QWidget();
        errorViewPage->setObjectName("errorViewPage");
        verticalLayout_3 = new QVBoxLayout(errorViewPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        errorView = new QPlainTextEdit(errorViewPage);
        errorView->setObjectName("errorView");
        errorView->setReadOnly(true);

        verticalLayout_3->addWidget(errorView);

        resultStack->addWidget(errorViewPage);
        splitter->addWidget(resultStack);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        horizontalLayout = new QHBoxLayout(layoutWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        queryEdit = new QPlainTextEdit(layoutWidget);
        queryEdit->setObjectName("queryEdit");

        horizontalLayout->addWidget(queryEdit);

        execButton = new QPushButton(layoutWidget);
        execButton->setObjectName("execButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(execButton->sizePolicy().hasHeightForWidth());
        execButton->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(execButton);

        splitter->addWidget(layoutWidget);

        verticalLayout_2->addWidget(splitter);


        retranslateUi(DbConsoleTab);

        resultStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DbConsoleTab);
    } // setupUi

    void retranslateUi(QWidget *DbConsoleTab)
    {
#if QT_CONFIG(tooltip)
        execButton->setToolTip(QCoreApplication::translate("DbConsoleTab", "Execute query", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)DbConsoleTab;
    } // retranslateUi

};

namespace Ui {
    class DbConsoleTab: public Ui_DbConsoleTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DBCONSOLETAB_H
