/********************************************************************************
** Form generated from reading UI file 'dbbrowser.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DBBROWSER_H
#define UI_DBBROWSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_DbBrowser
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    KComboBox *tableBox;
    QPushButton *refreshButton;
    QSpacerItem *spacerItem;
    QTableView *tableView;

    void setupUi(QWidget *DbBrowser)
    {
        if (DbBrowser->objectName().isEmpty())
            DbBrowser->setObjectName("DbBrowser");
        DbBrowser->resize(400, 300);
        verticalLayout = new QVBoxLayout(DbBrowser);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        tableBox = new KComboBox(DbBrowser);
        tableBox->setObjectName("tableBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tableBox->sizePolicy().hasHeightForWidth());
        tableBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(tableBox);

        refreshButton = new QPushButton(DbBrowser);
        refreshButton->setObjectName("refreshButton");

        horizontalLayout->addWidget(refreshButton);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem);


        verticalLayout->addLayout(horizontalLayout);

        tableView = new QTableView(DbBrowser);
        tableView->setObjectName("tableView");
        tableView->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));

        verticalLayout->addWidget(tableView);


        retranslateUi(DbBrowser);

        QMetaObject::connectSlotsByName(DbBrowser);
    } // setupUi

    void retranslateUi(QWidget *DbBrowser)
    {
        refreshButton->setText(QCoreApplication::translate("DbBrowser", "Refresh", nullptr));
        (void)DbBrowser;
    } // retranslateUi

};

namespace Ui {
    class DbBrowser: public Ui_DbBrowser {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DBBROWSER_H
