/********************************************************************************
** Form generated from reading UI file 'querydebugger.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUERYDEBUGGER_H
#define UI_QUERYDEBUGGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QueryDebugger
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *enableDebuggingChkBox;
    QTabWidget *tabWidget;
    QWidget *querySequenceTab;
    QVBoxLayout *verticalLayout_2;
    QTreeView *queryListView;
    QWidget *queryTreeTab;
    QVBoxLayout *verticalLayout_3;
    QTreeView *queryTreeView;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *saveToFileBtn;

    void setupUi(QWidget *QueryDebugger)
    {
        if (QueryDebugger->objectName().isEmpty())
            QueryDebugger->setObjectName("QueryDebugger");
        QueryDebugger->resize(645, 508);
        verticalLayout = new QVBoxLayout(QueryDebugger);
        verticalLayout->setObjectName("verticalLayout");
        enableDebuggingChkBox = new QCheckBox(QueryDebugger);
        enableDebuggingChkBox->setObjectName("enableDebuggingChkBox");

        verticalLayout->addWidget(enableDebuggingChkBox);

        tabWidget = new QTabWidget(QueryDebugger);
        tabWidget->setObjectName("tabWidget");
        querySequenceTab = new QWidget();
        querySequenceTab->setObjectName("querySequenceTab");
        verticalLayout_2 = new QVBoxLayout(querySequenceTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        queryListView = new QTreeView(querySequenceTab);
        queryListView->setObjectName("queryListView");
        queryListView->setRootIsDecorated(false);
        queryListView->setUniformRowHeights(true);
        queryListView->setSortingEnabled(true);

        verticalLayout_2->addWidget(queryListView);

        tabWidget->addTab(querySequenceTab, QString());
        queryTreeTab = new QWidget();
        queryTreeTab->setObjectName("queryTreeTab");
        verticalLayout_3 = new QVBoxLayout(queryTreeTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        queryTreeView = new QTreeView(queryTreeTab);
        queryTreeView->setObjectName("queryTreeView");

        verticalLayout_3->addWidget(queryTreeView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        saveToFileBtn = new QPushButton(queryTreeTab);
        saveToFileBtn->setObjectName("saveToFileBtn");

        horizontalLayout->addWidget(saveToFileBtn);


        verticalLayout_3->addLayout(horizontalLayout);

        tabWidget->addTab(queryTreeTab, QString());

        verticalLayout->addWidget(tabWidget);


        retranslateUi(QueryDebugger);

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(QueryDebugger);
    } // setupUi

    void retranslateUi(QWidget *QueryDebugger)
    {
        enableDebuggingChkBox->setText(QCoreApplication::translate("QueryDebugger", "Enable query debugging (slows down server!)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(querySequenceTab), QCoreApplication::translate("QueryDebugger", "Query Sequence", nullptr));
        saveToFileBtn->setText(QCoreApplication::translate("QueryDebugger", "Save To File", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(queryTreeTab), QCoreApplication::translate("QueryDebugger", "Query Tree", nullptr));
        (void)QueryDebugger;
    } // retranslateUi

};

namespace Ui {
    class QueryDebugger: public Ui_QueryDebugger {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QUERYDEBUGGER_H
