/********************************************************************************
** Form generated from reading UI file 'collectioninternalspage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLECTIONINTERNALSPAGE_H
#define UI_COLLECTIONINTERNALSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "keditlistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_CollectionInternalsPage
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *label_7;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *idLabel;
    QLabel *label_2;
    QLineEdit *ridEdit;
    QLabel *label_3;
    QLabel *resourceLabel;
    QLabel *label_4;
    QLineEdit *rrevEdit;
    QLabel *label_5;
    QCheckBox *virtCheck;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    KEditListWidget *contentTypes;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *CollectionInternalsPage)
    {
        if (CollectionInternalsPage->objectName().isEmpty())
            CollectionInternalsPage->setObjectName("CollectionInternalsPage");
        CollectionInternalsPage->resize(526, 442);
        vboxLayout = new QVBoxLayout(CollectionInternalsPage);
        vboxLayout->setObjectName("vboxLayout");
        label_7 = new QLabel(CollectionInternalsPage);
        label_7->setObjectName("label_7");

        vboxLayout->addWidget(label_7);

        groupBox = new QGroupBox(CollectionInternalsPage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        idLabel = new QLabel(groupBox);
        idLabel->setObjectName("idLabel");

        gridLayout->addWidget(idLabel, 0, 2, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        ridEdit = new QLineEdit(groupBox);
        ridEdit->setObjectName("ridEdit");

        gridLayout->addWidget(ridEdit, 1, 2, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        resourceLabel = new QLabel(groupBox);
        resourceLabel->setObjectName("resourceLabel");

        gridLayout->addWidget(resourceLabel, 3, 2, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        rrevEdit = new QLineEdit(groupBox);
        rrevEdit->setObjectName("rrevEdit");

        gridLayout->addWidget(rrevEdit, 2, 2, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        virtCheck = new QCheckBox(groupBox);
        virtCheck->setObjectName("virtCheck");

        gridLayout->addWidget(virtCheck, 4, 2, 1, 1);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(CollectionInternalsPage);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        contentTypes = new KEditListWidget(groupBox_2);
        contentTypes->setObjectName("contentTypes");
        contentTypes->setButtons(KEditListWidget::Add|KEditListWidget::Remove);

        verticalLayout->addWidget(contentTypes);


        vboxLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(ridEdit);
        label_4->setBuddy(rrevEdit);
        label_5->setBuddy(virtCheck);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CollectionInternalsPage);

        QMetaObject::connectSlotsByName(CollectionInternalsPage);
    } // setupUi

    void retranslateUi(QWidget *CollectionInternalsPage)
    {
        label_7->setStyleSheet(QCoreApplication::translate("CollectionInternalsPage", "font-weight:600;\n"
"color:#ff0000;", nullptr));
        label_7->setText(QCoreApplication::translate("CollectionInternalsPage", "Do not even think about changing anything in here!", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CollectionInternalsPage", "Identification", nullptr));
        label->setText(QCoreApplication::translate("CollectionInternalsPage", "Identifier:", nullptr));
        idLabel->setText(QString());
        label_2->setText(QCoreApplication::translate("CollectionInternalsPage", "Remote identifier:", nullptr));
        label_3->setText(QCoreApplication::translate("CollectionInternalsPage", "Owner:", nullptr));
        resourceLabel->setText(QString());
        label_4->setText(QCoreApplication::translate("CollectionInternalsPage", "Remote Revision:", nullptr));
        label_5->setText(QCoreApplication::translate("CollectionInternalsPage", "Virtual:", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("CollectionInternalsPage", "Content Types", nullptr));
        contentTypes->setProperty("title", QVariant(QCoreApplication::translate("CollectionInternalsPage", "Content Types", nullptr)));
        (void)CollectionInternalsPage;
    } // retranslateUi

};

namespace Ui {
    class CollectionInternalsPage: public Ui_CollectionInternalsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLLECTIONINTERNALSPAGE_H
