/****************************************************************************
** Meta object code from reading C++ file 'jobtrackeradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "jobtrackeradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jobtrackeradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17JobTrackerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto JobTrackerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17JobTrackerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JobTrackerAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.JobTracker",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.JobTracker\">\n    <si"
        "gnal name=\"aboutToAdd\">\n      <arg direction=\"out\" type=\"i\""
        " name=\"pos\"/>\n      <arg direction=\"out\" type=\"i\" name=\"pa"
        "rentId\"/>\n    </signal>\n    <signal name=\"added\"/>\n    <meth"
        "od name=\"jobCreated\">\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"session\"/>\n      <arg direction=\"in\" type=\"s\" name=\"jo"
        "bName\"/>\n      <arg direction=\"in\" type=\"s\" name=\"parentJob"
        "\"/>\n      <arg direction=\"in\" type=\"s\" name=\"jobType\"/>\n "
        "     <arg direction=\"in\" type=\"s\" name=\"debugString\"/>\n    "
        "</method>\n    <method name=\"jobStarted\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"jobName\"/>\n    </method>\n    <method n"
        "ame=\"jobEnded\">\n      <arg direction=\"in\" type=\"s\" name=\"j"
        "obName\"/>\n      <arg direction=\"in\" type=\"s\" name=\"error\"/"
        ">\n    </method>\n    <method name=\"setEnabled\">\n      <arg dir"
        "ection=\"in\" type=\"b\" name=\"on\"/>\n    </method>\n    <method"
        " name=\"signalUpdates\"/>\n  </interface>\n",
        "aboutToAdd",
        "",
        "pos",
        "parentId",
        "added",
        "jobCreated",
        "session",
        "jobName",
        "parentJob",
        "jobType",
        "debugString",
        "jobEnded",
        "error",
        "jobStarted",
        "setEnabled",
        "on",
        "signalUpdates"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToAdd'
        QtMocHelpers::SignalData<void(int, int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'added'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jobCreated'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
            { QMetaType::QString, 15 },
        }}),
        // Slot 'jobEnded'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'jobStarted'
        QtMocHelpers::SlotData<void(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'signalUpdates'
        QtMocHelpers::SlotData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<JobTrackerAdaptor, qt_meta_tag_ZN17JobTrackerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject JobTrackerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17JobTrackerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17JobTrackerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17JobTrackerAdaptorE_t>.metaTypes,
    nullptr
} };

void JobTrackerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JobTrackerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToAdd((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->added(); break;
        case 2: _t->jobCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 3: _t->jobEnded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->jobStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->signalUpdates(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JobTrackerAdaptor::*)(int , int )>(_a, &JobTrackerAdaptor::aboutToAdd, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JobTrackerAdaptor::*)()>(_a, &JobTrackerAdaptor::added, 1))
            return;
    }
}

const QMetaObject *JobTrackerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JobTrackerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17JobTrackerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int JobTrackerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void JobTrackerAdaptor::aboutToAdd(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void JobTrackerAdaptor::added()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
