/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.akonadiconsole.logger.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "loggeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class LoggerAdaptor
 */

LoggerAdaptor::LoggerAdaptor(Logging *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

LoggerAdaptor::~LoggerAdaptor()
{
    // destructor
}

bool LoggerAdaptor::enabled()
{
    // handle method call org.kde.akonadiconsole.logger.enabled
    return parent()->enabled();
}

void LoggerAdaptor::message(qlonglong timestamp, const QString &app, qlonglong pid, int type, const QString &category, const QString &file, const QString &function, int line, int version, const QString &msg)
{
    // handle method call org.kde.akonadiconsole.logger.message
    parent()->message(timestamp, app, pid, type, category, file, function, line, version, msg);
}


#include "moc_loggeradaptor.cpp"
