/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.JobTracker.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "jobtrackeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class JobTrackerAdaptor
 */

JobTrackerAdaptor::JobTrackerAdaptor(JobTracker *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

JobTrackerAdaptor::~JobTrackerAdaptor()
{
    // destructor
}

void JobTrackerAdaptor::jobCreated(const QString &session, const QString &jobName, const QString &parentJob, const QString &jobType, const QString &debugString)
{
    // handle method call org.freedesktop.Akonadi.JobTracker.jobCreated
    parent()->jobCreated(session, jobName, parentJob, jobType, debugString);
}

void JobTrackerAdaptor::jobEnded(const QString &jobName, const QString &error)
{
    // handle method call org.freedesktop.Akonadi.JobTracker.jobEnded
    parent()->jobEnded(jobName, error);
}

void JobTrackerAdaptor::jobStarted(const QString &jobName)
{
    // handle method call org.freedesktop.Akonadi.JobTracker.jobStarted
    parent()->jobStarted(jobName);
}

void JobTrackerAdaptor::setEnabled(bool on)
{
    // handle method call org.freedesktop.Akonadi.JobTracker.setEnabled
    parent()->setEnabled(on);
}

void JobTrackerAdaptor::signalUpdates()
{
    // handle method call org.freedesktop.Akonadi.JobTracker.signalUpdates
    parent()->signalUpdates();
}


#include "moc_jobtrackeradaptor.cpp"
