/********************************************************************************
** Form generated from reading UI file 'browserwidget_contentview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BROWSERWIDGET_CONTENTVIEW_H
#define UI_BROWSERWIDGET_CONTENTVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "keditlistwidget.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_ContentViewWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QPushButton *saveButton;
    QTabWidget *mainTabWidget;
    QWidget *tab;
    QVBoxLayout *vboxLayout;
    QStackedWidget *stack;
    QWidget *unsupportedTypePage;
    QVBoxLayout *vboxLayout1;
    QLabel *unsupportedType;
    QWidget *imageViewPage;
    QVBoxLayout *verticalLayout_3;
    QLabel *imageView;
    QWidget *tab_4;
    QGridLayout *gridLayout1;
    QTreeView *attrView;
    QLineEdit *attrName;
    QPushButton *attrAddButton;
    QPushButton *attrDeleteButton;
    QWidget *tab_2;
    QGridLayout *gridLayout2;
    KTextEdit *dataView;
    QWidget *tab_3;
    QGridLayout *gridLayout3;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *label_2;
    QLabel *id;
    QHBoxLayout *hboxLayout1;
    QLabel *label_4;
    QLineEdit *remoteId;
    QHBoxLayout *hboxLayout2;
    QLabel *label_gid;
    QLineEdit *gid;
    QHBoxLayout *hboxLayout3;
    QLabel *label_3;
    QLabel *revision;
    QHBoxLayout *hboxLayout4;
    QLabel *label_7;
    QLabel *size;
    QHBoxLayout *hboxLayout5;
    QLabel *label_5;
    QLabel *modificationtime;
    QHBoxLayout *hboxLayout6;
    QLabel *label_6;
    QLabel *mimeType;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_6;
    KEditListWidget *flags;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    KEditListWidget *tags;

    void setupUi(QWidget *ContentViewWidget)
    {
        if (ContentViewWidget->objectName().isEmpty())
            ContentViewWidget->setObjectName("ContentViewWidget");
        ContentViewWidget->resize(622, 604);
        gridLayout = new QGridLayout(ContentViewWidget);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 0, 1, 1);

        saveButton = new QPushButton(ContentViewWidget);
        saveButton->setObjectName("saveButton");

        gridLayout->addWidget(saveButton, 1, 1, 1, 1);

        mainTabWidget = new QTabWidget(ContentViewWidget);
        mainTabWidget->setObjectName("mainTabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout = new QVBoxLayout(tab);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        stack = new QStackedWidget(tab);
        stack->setObjectName("stack");
        stack->setFrameShadow(QFrame::Sunken);
        unsupportedTypePage = new QWidget();
        unsupportedTypePage->setObjectName("unsupportedTypePage");
        vboxLayout1 = new QVBoxLayout(unsupportedTypePage);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        unsupportedType = new QLabel(unsupportedTypePage);
        unsupportedType->setObjectName("unsupportedType");
        unsupportedType->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(unsupportedType);

        stack->addWidget(unsupportedTypePage);
        imageViewPage = new QWidget();
        imageViewPage->setObjectName("imageViewPage");
        verticalLayout_3 = new QVBoxLayout(imageViewPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        imageView = new QLabel(imageViewPage);
        imageView->setObjectName("imageView");

        verticalLayout_3->addWidget(imageView);

        stack->addWidget(imageViewPage);

        vboxLayout->addWidget(stack);

        mainTabWidget->addTab(tab, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout1 = new QGridLayout(tab_4);
        gridLayout1->setObjectName("gridLayout1");
        attrView = new QTreeView(tab_4);
        attrView->setObjectName("attrView");
        attrView->setRootIsDecorated(false);

        gridLayout1->addWidget(attrView, 0, 0, 1, 3);

        attrName = new QLineEdit(tab_4);
        attrName->setObjectName("attrName");

        gridLayout1->addWidget(attrName, 1, 0, 1, 1);

        attrAddButton = new QPushButton(tab_4);
        attrAddButton->setObjectName("attrAddButton");

        gridLayout1->addWidget(attrAddButton, 1, 1, 1, 1);

        attrDeleteButton = new QPushButton(tab_4);
        attrDeleteButton->setObjectName("attrDeleteButton");

        gridLayout1->addWidget(attrDeleteButton, 1, 2, 1, 1);

        mainTabWidget->addTab(tab_4, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout2 = new QGridLayout(tab_2);
        gridLayout2->setObjectName("gridLayout2");
        dataView = new KTextEdit(tab_2);
        dataView->setObjectName("dataView");
        dataView->setLineWrapMode(QTextEdit::NoWrap);
        dataView->setAcceptRichText(false);

        gridLayout2->addWidget(dataView, 0, 0, 1, 2);

        mainTabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout3 = new QGridLayout(tab_3);
        gridLayout3->setObjectName("gridLayout3");
        scrollArea = new QScrollArea(tab_3);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 586, 501));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_2 = new QLabel(scrollAreaWidgetContents);
        label_2->setObjectName("label_2");

        hboxLayout->addWidget(label_2);

        id = new QLabel(scrollAreaWidgetContents);
        id->setObjectName("id");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(id->sizePolicy().hasHeightForWidth());
        id->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(id);


        verticalLayout_2->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_4 = new QLabel(scrollAreaWidgetContents);
        label_4->setObjectName("label_4");

        hboxLayout1->addWidget(label_4);

        remoteId = new QLineEdit(scrollAreaWidgetContents);
        remoteId->setObjectName("remoteId");

        hboxLayout1->addWidget(remoteId);


        verticalLayout_2->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        label_gid = new QLabel(scrollAreaWidgetContents);
        label_gid->setObjectName("label_gid");

        hboxLayout2->addWidget(label_gid);

        gid = new QLineEdit(scrollAreaWidgetContents);
        gid->setObjectName("gid");

        hboxLayout2->addWidget(gid);


        verticalLayout_2->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        label_3 = new QLabel(scrollAreaWidgetContents);
        label_3->setObjectName("label_3");

        hboxLayout3->addWidget(label_3);

        revision = new QLabel(scrollAreaWidgetContents);
        revision->setObjectName("revision");
        sizePolicy.setHeightForWidth(revision->sizePolicy().hasHeightForWidth());
        revision->setSizePolicy(sizePolicy);

        hboxLayout3->addWidget(revision);


        verticalLayout_2->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        label_7 = new QLabel(scrollAreaWidgetContents);
        label_7->setObjectName("label_7");

        hboxLayout4->addWidget(label_7);

        size = new QLabel(scrollAreaWidgetContents);
        size->setObjectName("size");
        sizePolicy.setHeightForWidth(size->sizePolicy().hasHeightForWidth());
        size->setSizePolicy(sizePolicy);

        hboxLayout4->addWidget(size);


        verticalLayout_2->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setObjectName("hboxLayout5");
        label_5 = new QLabel(scrollAreaWidgetContents);
        label_5->setObjectName("label_5");

        hboxLayout5->addWidget(label_5);

        modificationtime = new QLabel(scrollAreaWidgetContents);
        modificationtime->setObjectName("modificationtime");
        sizePolicy.setHeightForWidth(modificationtime->sizePolicy().hasHeightForWidth());
        modificationtime->setSizePolicy(sizePolicy);

        hboxLayout5->addWidget(modificationtime);


        verticalLayout_2->addLayout(hboxLayout5);

        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setObjectName("hboxLayout6");
        label_6 = new QLabel(scrollAreaWidgetContents);
        label_6->setObjectName("label_6");

        hboxLayout6->addWidget(label_6);

        mimeType = new QLabel(scrollAreaWidgetContents);
        mimeType->setObjectName("mimeType");
        sizePolicy.setHeightForWidth(mimeType->sizePolicy().hasHeightForWidth());
        mimeType->setSizePolicy(sizePolicy);

        hboxLayout6->addWidget(mimeType);


        verticalLayout_2->addLayout(hboxLayout6);

        groupBox = new QGroupBox(scrollAreaWidgetContents);
        groupBox->setObjectName("groupBox");
        verticalLayout_6 = new QVBoxLayout(groupBox);
        verticalLayout_6->setObjectName("verticalLayout_6");
        flags = new KEditListWidget(groupBox);
        flags->setObjectName("flags");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(flags->sizePolicy().hasHeightForWidth());
        flags->setSizePolicy(sizePolicy1);
        flags->setButtons(KEditListWidget::Add|KEditListWidget::Remove);

        verticalLayout_6->addWidget(flags);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(scrollAreaWidgetContents);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        tags = new KEditListWidget(groupBox_2);
        tags->setObjectName("tags");
        sizePolicy1.setHeightForWidth(tags->sizePolicy().hasHeightForWidth());
        tags->setSizePolicy(sizePolicy1);
        tags->setButtons(KEditListWidget::Add|KEditListWidget::Remove);

        verticalLayout->addWidget(tags);


        verticalLayout_2->addWidget(groupBox_2);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout3->addWidget(scrollArea, 0, 0, 1, 1);

        mainTabWidget->addTab(tab_3, QString());

        gridLayout->addWidget(mainTabWidget, 0, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label_4->setBuddy(remoteId);
        label_gid->setBuddy(gid);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ContentViewWidget);

        mainTabWidget->setCurrentIndex(0);
        stack->setCurrentIndex(3);


        QMetaObject::connectSlotsByName(ContentViewWidget);
    } // setupUi

    void retranslateUi(QWidget *ContentViewWidget)
    {
        saveButton->setText(QCoreApplication::translate("ContentViewWidget", "&Save", nullptr));
        unsupportedType->setText(QCoreApplication::translate("ContentViewWidget", "Unsupported Type", nullptr));
        mainTabWidget->setTabText(mainTabWidget->indexOf(tab), QCoreApplication::translate("ContentViewWidget", "Payload", nullptr));
        attrName->setPlaceholderText(QCoreApplication::translate("ContentViewWidget", "New Attribute", nullptr));
        attrAddButton->setText(QCoreApplication::translate("ContentViewWidget", "&Add", nullptr));
        attrDeleteButton->setText(QCoreApplication::translate("ContentViewWidget", "&Delete", nullptr));
        mainTabWidget->setTabText(mainTabWidget->indexOf(tab_4), QCoreApplication::translate("ContentViewWidget", "Attributes", nullptr));
        mainTabWidget->setTabText(mainTabWidget->indexOf(tab_2), QCoreApplication::translate("ContentViewWidget", "Raw Payload", nullptr));
        label_2->setText(QCoreApplication::translate("ContentViewWidget", "Unique ID:", nullptr));
        id->setText(QCoreApplication::translate("ContentViewWidget", "0", nullptr));
        label_4->setText(QCoreApplication::translate("ContentViewWidget", "Remote ID:", nullptr));
        label_gid->setText(QCoreApplication::translate("ContentViewWidget", "GID:", nullptr));
        label_3->setText(QCoreApplication::translate("ContentViewWidget", "Revision:", nullptr));
        revision->setText(QCoreApplication::translate("ContentViewWidget", "0", nullptr));
        label_7->setText(QCoreApplication::translate("ContentViewWidget", "Size:", nullptr));
        size->setText(QCoreApplication::translate("ContentViewWidget", "0", nullptr));
        label_5->setText(QCoreApplication::translate("ContentViewWidget", "Last modification time:", nullptr));
        modificationtime->setText(QCoreApplication::translate("ContentViewWidget", "0", nullptr));
        label_6->setText(QCoreApplication::translate("ContentViewWidget", "Mimetype:", nullptr));
        mimeType->setText(QCoreApplication::translate("ContentViewWidget", "invalid/invalid", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ContentViewWidget", "Flags", nullptr));
        flags->setProperty("title", QVariant(QCoreApplication::translate("ContentViewWidget", "Flags", nullptr)));
        groupBox_2->setTitle(QCoreApplication::translate("ContentViewWidget", "Tags", nullptr));
        tags->setProperty("title", QVariant(QCoreApplication::translate("ContentViewWidget", "Flags", nullptr)));
        mainTabWidget->setTabText(mainTabWidget->indexOf(tab_3), QCoreApplication::translate("ContentViewWidget", "Internals", nullptr));
        (void)ContentViewWidget;
    } // retranslateUi

};

namespace Ui {
    class ContentViewWidget: public Ui_ContentViewWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BROWSERWIDGET_CONTENTVIEW_H
