/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.JobTracker.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef JOBTRACKERADAPTOR_H
#define JOBTRACKERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "jobtracker.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.JobTracker
 */
class JobTrackerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.JobTracker")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.JobTracker\">\n"
"    <signal name=\"aboutToAdd\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"pos\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"parentId\"/>\n"
"    </signal>\n"
"    <signal name=\"added\"/>\n"
"    <method name=\"jobCreated\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"session\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"jobName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"parentJob\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"jobType\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"debugString\"/>\n"
"    </method>\n"
"    <method name=\"jobStarted\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"jobName\"/>\n"
"    </method>\n"
"    <method name=\"jobEnded\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"jobName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"error\"/>\n"
"    </method>\n"
"    <method name=\"setEnabled\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"on\"/>\n"
"    </method>\n"
"    <method name=\"signalUpdates\"/>\n"
"  </interface>\n"
        "")
public:
    JobTrackerAdaptor(JobTracker *parent);
    ~JobTrackerAdaptor() override;

    inline JobTracker *parent() const
    { return static_cast<JobTracker *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void jobCreated(const QString &session, const QString &jobName, const QString &parentJob, const QString &jobType, const QString &debugString);
    void jobEnded(const QString &jobName, const QString &error);
    void jobStarted(const QString &jobName);
    void setEnabled(bool on);
    void signalUpdates();
Q_SIGNALS: // SIGNALS
    void aboutToAdd(int pos, int parentId);
    void added();
};

#endif
