/********************************************************************************
** Form generated from reading UI file 'agentwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AGENTWIDGET_H
#define UI_AGENTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "Akonadi/AgentInstanceWidget"

QT_BEGIN_NAMESPACE

class Ui_AgentWidget
{
public:
    QGridLayout *gridLayout;
    QLineEdit *mFilterAccount;
    Akonadi::AgentInstanceWidget *instanceWidget;
    QGroupBox *detailsBox;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *identifierLabel;
    QLabel *label_3;
    QLabel *typeLabel;
    QLabel *label_5;
    QLabel *statusLabel;
    QLabel *label_6;
    QLabel *statusMessageLabel;
    QLabel *label_7;
    QLabel *capabilitiesLabel;
    QLabel *label_9;
    QLabel *mimeTypeLabel;
    QLabel *label_10;
    QLabel *accountIdLabel;
    QSpacerItem *horizontalSpacer;
    QPushButton *addButton;
    QPushButton *removeButton;
    QPushButton *configButton;
    QPushButton *abortButton;
    QPushButton *syncButton;
    QPushButton *restartButton;

    void setupUi(QWidget *AgentWidget)
    {
        if (AgentWidget->objectName().isEmpty())
            AgentWidget->setObjectName("AgentWidget");
        AgentWidget->resize(662, 633);
        gridLayout = new QGridLayout(AgentWidget);
        gridLayout->setObjectName("gridLayout");
        mFilterAccount = new QLineEdit(AgentWidget);
        mFilterAccount->setObjectName("mFilterAccount");
        mFilterAccount->setClearButtonEnabled(true);

        gridLayout->addWidget(mFilterAccount, 0, 0, 1, 7);

        instanceWidget = new Akonadi::AgentInstanceWidget(AgentWidget);
        instanceWidget->setObjectName("instanceWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(instanceWidget->sizePolicy().hasHeightForWidth());
        instanceWidget->setSizePolicy(sizePolicy);
        instanceWidget->setContextMenuPolicy(Qt::CustomContextMenu);

        gridLayout->addWidget(instanceWidget, 1, 0, 1, 7);

        detailsBox = new QGroupBox(AgentWidget);
        detailsBox->setObjectName("detailsBox");
        formLayout = new QFormLayout(detailsBox);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(detailsBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        identifierLabel = new QLabel(detailsBox);
        identifierLabel->setObjectName("identifierLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(identifierLabel->sizePolicy().hasHeightForWidth());
        identifierLabel->setSizePolicy(sizePolicy1);
        identifierLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, identifierLabel);

        label_3 = new QLabel(detailsBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        typeLabel = new QLabel(detailsBox);
        typeLabel->setObjectName("typeLabel");
        sizePolicy1.setHeightForWidth(typeLabel->sizePolicy().hasHeightForWidth());
        typeLabel->setSizePolicy(sizePolicy1);
        typeLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, typeLabel);

        label_5 = new QLabel(detailsBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        statusLabel = new QLabel(detailsBox);
        statusLabel->setObjectName("statusLabel");
        sizePolicy1.setHeightForWidth(statusLabel->sizePolicy().hasHeightForWidth());
        statusLabel->setSizePolicy(sizePolicy1);
        statusLabel->setWordWrap(true);
        statusLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, statusLabel);

        label_6 = new QLabel(detailsBox);
        label_6->setObjectName("label_6");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_6);

        statusMessageLabel = new QLabel(detailsBox);
        statusMessageLabel->setObjectName("statusMessageLabel");
        sizePolicy1.setHeightForWidth(statusMessageLabel->sizePolicy().hasHeightForWidth());
        statusMessageLabel->setSizePolicy(sizePolicy1);
        statusMessageLabel->setWordWrap(true);
        statusMessageLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, statusMessageLabel);

        label_7 = new QLabel(detailsBox);
        label_7->setObjectName("label_7");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_7);

        capabilitiesLabel = new QLabel(detailsBox);
        capabilitiesLabel->setObjectName("capabilitiesLabel");
        sizePolicy1.setHeightForWidth(capabilitiesLabel->sizePolicy().hasHeightForWidth());
        capabilitiesLabel->setSizePolicy(sizePolicy1);
        capabilitiesLabel->setWordWrap(true);
        capabilitiesLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, capabilitiesLabel);

        label_9 = new QLabel(detailsBox);
        label_9->setObjectName("label_9");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_9);

        mimeTypeLabel = new QLabel(detailsBox);
        mimeTypeLabel->setObjectName("mimeTypeLabel");
        sizePolicy1.setHeightForWidth(mimeTypeLabel->sizePolicy().hasHeightForWidth());
        mimeTypeLabel->setSizePolicy(sizePolicy1);
        mimeTypeLabel->setWordWrap(true);
        mimeTypeLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, mimeTypeLabel);

        label_10 = new QLabel(detailsBox);
        label_10->setObjectName("label_10");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_10);

        accountIdLabel = new QLabel(detailsBox);
        accountIdLabel->setObjectName("accountIdLabel");
        sizePolicy1.setHeightForWidth(accountIdLabel->sizePolicy().hasHeightForWidth());
        accountIdLabel->setSizePolicy(sizePolicy1);
        accountIdLabel->setWordWrap(true);
        accountIdLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, accountIdLabel);


        gridLayout->addWidget(detailsBox, 2, 0, 1, 7);

        horizontalSpacer = new QSpacerItem(154, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 3, 0, 1, 1);

        addButton = new QPushButton(AgentWidget);
        addButton->setObjectName("addButton");

        gridLayout->addWidget(addButton, 3, 1, 1, 1);

        removeButton = new QPushButton(AgentWidget);
        removeButton->setObjectName("removeButton");

        gridLayout->addWidget(removeButton, 3, 2, 1, 1);

        configButton = new QPushButton(AgentWidget);
        configButton->setObjectName("configButton");

        gridLayout->addWidget(configButton, 3, 3, 1, 1);

        abortButton = new QPushButton(AgentWidget);
        abortButton->setObjectName("abortButton");

        gridLayout->addWidget(abortButton, 3, 4, 1, 1);

        syncButton = new QPushButton(AgentWidget);
        syncButton->setObjectName("syncButton");

        gridLayout->addWidget(syncButton, 3, 5, 1, 1);

        restartButton = new QPushButton(AgentWidget);
        restartButton->setObjectName("restartButton");

        gridLayout->addWidget(restartButton, 3, 6, 1, 1);


        retranslateUi(AgentWidget);

        QMetaObject::connectSlotsByName(AgentWidget);
    } // setupUi

    void retranslateUi(QWidget *AgentWidget)
    {
        detailsBox->setTitle(QCoreApplication::translate("AgentWidget", "Details", nullptr));
        label->setText(QCoreApplication::translate("AgentWidget", "Identifier:", nullptr));
        identifierLabel->setText(QString());
        label_3->setText(QCoreApplication::translate("AgentWidget", "Type:", nullptr));
        typeLabel->setText(QString());
        label_5->setText(QCoreApplication::translate("AgentWidget", "Status:", nullptr));
        statusLabel->setText(QString());
        label_6->setText(QCoreApplication::translate("AgentWidget", "Status Message:", nullptr));
        statusMessageLabel->setText(QString());
        label_7->setText(QCoreApplication::translate("AgentWidget", "Capabilities:", nullptr));
        capabilitiesLabel->setText(QString());
        label_9->setText(QCoreApplication::translate("AgentWidget", "Mimetypes:", nullptr));
        mimeTypeLabel->setText(QString());
        label_10->setText(QCoreApplication::translate("AgentWidget", "Account ID:", nullptr));
        accountIdLabel->setText(QString());
        addButton->setText(QCoreApplication::translate("AgentWidget", "Add...", nullptr));
        removeButton->setText(QCoreApplication::translate("AgentWidget", "Remove", nullptr));
        configButton->setText(QCoreApplication::translate("AgentWidget", "Configure...", nullptr));
        abortButton->setText(QCoreApplication::translate("AgentWidget", "Abort", nullptr));
        syncButton->setText(QCoreApplication::translate("AgentWidget", "Synchronize", nullptr));
        restartButton->setText(QCoreApplication::translate("AgentWidget", "Restart", "restart the agent"));
        (void)AgentWidget;
    } // retranslateUi

};

namespace Ui {
    class AgentWidget: public Ui_AgentWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AGENTWIDGET_H
