/********************************************************************************
** Form generated from reading UI file 'agentconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AGENTCONFIGDIALOG_H
#define UI_AGENTCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AgentConfigDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTreeView *propertyView;

    void setupUi(QWidget *AgentConfigDialog)
    {
        if (AgentConfigDialog->objectName().isEmpty())
            AgentConfigDialog->setObjectName("AgentConfigDialog");
        AgentConfigDialog->resize(400, 300);
        verticalLayout = new QVBoxLayout(AgentConfigDialog);
        verticalLayout->setObjectName("verticalLayout");
        propertyView = new QTreeView(AgentConfigDialog);
        propertyView->setObjectName("propertyView");
        propertyView->setEditTriggers(QAbstractItemView::AllEditTriggers);
        propertyView->setRootIsDecorated(false);
        propertyView->setAllColumnsShowFocus(true);

        verticalLayout->addWidget(propertyView);


        retranslateUi(AgentConfigDialog);

        QMetaObject::connectSlotsByName(AgentConfigDialog);
    } // setupUi

    void retranslateUi(QWidget *AgentConfigDialog)
    {
        (void)AgentConfigDialog;
    } // retranslateUi

};

namespace Ui {
    class AgentConfigDialog: public Ui_AgentConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AGENTCONFIGDIALOG_H
