/********************************************************************************
** Form generated from reading UI file 'queryviewdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUERYVIEWDIALOG_H
#define UI_QUERYVIEWDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_QueryViewDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QLabel *queryLabelLbl;
    QLabel *queryLbl;
    QLabel *resultsLabelLbl;
    QLabel *resultsLbl;
    QTableWidget *tableWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QueryViewDialog)
    {
        if (QueryViewDialog->objectName().isEmpty())
            QueryViewDialog->setObjectName("QueryViewDialog");
        QueryViewDialog->resize(665, 518);
        verticalLayout_2 = new QVBoxLayout(QueryViewDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        queryLabelLbl = new QLabel(QueryViewDialog);
        queryLabelLbl->setObjectName("queryLabelLbl");
        QFont font;
        font.setBold(true);
        queryLabelLbl->setFont(font);

        gridLayout->addWidget(queryLabelLbl, 0, 0, 1, 1);

        queryLbl = new QLabel(QueryViewDialog);
        queryLbl->setObjectName("queryLbl");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(queryLbl->sizePolicy().hasHeightForWidth());
        queryLbl->setSizePolicy(sizePolicy);
        queryLbl->setWordWrap(true);
        queryLbl->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(queryLbl, 0, 1, 1, 1);

        resultsLabelLbl = new QLabel(QueryViewDialog);
        resultsLabelLbl->setObjectName("resultsLabelLbl");
        resultsLabelLbl->setFont(font);

        gridLayout->addWidget(resultsLabelLbl, 1, 0, 1, 1);

        resultsLbl = new QLabel(QueryViewDialog);
        resultsLbl->setObjectName("resultsLbl");

        gridLayout->addWidget(resultsLbl, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        tableWidget = new QTableWidget(QueryViewDialog);
        tableWidget->setObjectName("tableWidget");

        verticalLayout_2->addWidget(tableWidget);

        buttonBox = new QDialogButtonBox(QueryViewDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(QueryViewDialog);

        QMetaObject::connectSlotsByName(QueryViewDialog);
    } // setupUi

    void retranslateUi(QDialog *QueryViewDialog)
    {
        QueryViewDialog->setWindowTitle(QCoreApplication::translate("QueryViewDialog", "Query View", nullptr));
        queryLabelLbl->setText(QCoreApplication::translate("QueryViewDialog", "Query:", nullptr));
        queryLbl->setText(QCoreApplication::translate("QueryViewDialog", "TextLabel", nullptr));
        resultsLabelLbl->setText(QCoreApplication::translate("QueryViewDialog", "Results:", nullptr));
        resultsLbl->setText(QCoreApplication::translate("QueryViewDialog", "TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QueryViewDialog: public Ui_QueryViewDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QUERYVIEWDIALOG_H
