/********************************************************************************
** Form generated from reading UI file 'tagpropertiesdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAGPROPERTIESDIALOG_H
#define UI_TAGPROPERTIESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_TagPropertiesDialog
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *generalTab;
    QFormLayout *formLayout;
    QLabel *idLabelBuddy;
    QLabel *idLabel;
    QLabel *label_2;
    KLineEdit *gidEdit;
    QLabel *parentIdLabelBuddy;
    QLabel *parentIdLabel;
    QLabel *label_4;
    KLineEdit *typeEdit;
    QWidget *attributesTab;
    QGridLayout *gridLayout_2;
    KLineEdit *newAttrEdit;
    QPushButton *addAttrButton;
    QPushButton *deleteAttrButton;
    QTreeView *attrsView;
    QWidget *remoteIDsTab;
    QGridLayout *gridLayout_3;
    KLineEdit *newRIDEdit;
    QPushButton *deleteRIDButton;
    QTreeView *ridsView;
    QPushButton *addRIDButton;
    QLabel *label_5;

    void setupUi(QWidget *TagPropertiesDialog)
    {
        if (TagPropertiesDialog->objectName().isEmpty())
            TagPropertiesDialog->setObjectName("TagPropertiesDialog");
        TagPropertiesDialog->resize(569, 359);
        gridLayout = new QGridLayout(TagPropertiesDialog);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(TagPropertiesDialog);
        tabWidget->setObjectName("tabWidget");
        generalTab = new QWidget();
        generalTab->setObjectName("generalTab");
        formLayout = new QFormLayout(generalTab);
        formLayout->setObjectName("formLayout");
        idLabelBuddy = new QLabel(generalTab);
        idLabelBuddy->setObjectName("idLabelBuddy");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, idLabelBuddy);

        idLabel = new QLabel(generalTab);
        idLabel->setObjectName("idLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, idLabel);

        label_2 = new QLabel(generalTab);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        gidEdit = new KLineEdit(generalTab);
        gidEdit->setObjectName("gidEdit");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, gidEdit);

        parentIdLabelBuddy = new QLabel(generalTab);
        parentIdLabelBuddy->setObjectName("parentIdLabelBuddy");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, parentIdLabelBuddy);

        parentIdLabel = new QLabel(generalTab);
        parentIdLabel->setObjectName("parentIdLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, parentIdLabel);

        label_4 = new QLabel(generalTab);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        typeEdit = new KLineEdit(generalTab);
        typeEdit->setObjectName("typeEdit");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, typeEdit);

        tabWidget->addTab(generalTab, QString());
        attributesTab = new QWidget();
        attributesTab->setObjectName("attributesTab");
        gridLayout_2 = new QGridLayout(attributesTab);
        gridLayout_2->setObjectName("gridLayout_2");
        newAttrEdit = new KLineEdit(attributesTab);
        newAttrEdit->setObjectName("newAttrEdit");

        gridLayout_2->addWidget(newAttrEdit, 1, 0, 1, 1);

        addAttrButton = new QPushButton(attributesTab);
        addAttrButton->setObjectName("addAttrButton");

        gridLayout_2->addWidget(addAttrButton, 1, 1, 1, 1);

        deleteAttrButton = new QPushButton(attributesTab);
        deleteAttrButton->setObjectName("deleteAttrButton");

        gridLayout_2->addWidget(deleteAttrButton, 1, 2, 1, 1);

        attrsView = new QTreeView(attributesTab);
        attrsView->setObjectName("attrsView");

        gridLayout_2->addWidget(attrsView, 0, 0, 1, 3);

        tabWidget->addTab(attributesTab, QString());
        remoteIDsTab = new QWidget();
        remoteIDsTab->setObjectName("remoteIDsTab");
        gridLayout_3 = new QGridLayout(remoteIDsTab);
        gridLayout_3->setObjectName("gridLayout_3");
        newRIDEdit = new KLineEdit(remoteIDsTab);
        newRIDEdit->setObjectName("newRIDEdit");

        gridLayout_3->addWidget(newRIDEdit, 4, 0, 1, 1);

        deleteRIDButton = new QPushButton(remoteIDsTab);
        deleteRIDButton->setObjectName("deleteRIDButton");

        gridLayout_3->addWidget(deleteRIDButton, 4, 2, 1, 1);

        ridsView = new QTreeView(remoteIDsTab);
        ridsView->setObjectName("ridsView");

        gridLayout_3->addWidget(ridsView, 1, 0, 3, 3);

        addRIDButton = new QPushButton(remoteIDsTab);
        addRIDButton->setObjectName("addRIDButton");

        gridLayout_3->addWidget(addRIDButton, 4, 1, 1, 1);

        label_5 = new QLabel(remoteIDsTab);
        label_5->setObjectName("label_5");
        QPalette palette;
        QBrush brush(QColor(255, 0, 0, 255));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::ButtonText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::ButtonText, brush);
        QBrush brush1(QColor(96, 95, 94, 255));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush1);
        QBrush brush2(QColor(83, 82, 81, 255));
        brush2.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush2);
        QBrush brush3(QColor(108, 106, 105, 255));
        brush3.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::ButtonText, brush3);
        label_5->setPalette(palette);
        QFont font;
        font.setBold(true);
        label_5->setFont(font);

        gridLayout_3->addWidget(label_5, 0, 0, 1, 1);

        gridLayout_3->setRowStretch(1, 1);
        tabWidget->addTab(remoteIDsTab, QString());

        gridLayout->addWidget(tabWidget, 0, 1, 1, 1);


        retranslateUi(TagPropertiesDialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(TagPropertiesDialog);
    } // setupUi

    void retranslateUi(QWidget *TagPropertiesDialog)
    {
        idLabelBuddy->setText(QCoreApplication::translate("TagPropertiesDialog", "Identifier:", nullptr));
        idLabel->setText(QString());
        label_2->setText(QCoreApplication::translate("TagPropertiesDialog", "GID:", nullptr));
        parentIdLabelBuddy->setText(QCoreApplication::translate("TagPropertiesDialog", "Parent Tag Id:", nullptr));
        parentIdLabel->setText(QString());
        label_4->setText(QCoreApplication::translate("TagPropertiesDialog", "Type:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(generalTab), QCoreApplication::translate("TagPropertiesDialog", "General", nullptr));
        newAttrEdit->setPlaceholderText(QCoreApplication::translate("TagPropertiesDialog", "New Attribute", nullptr));
        addAttrButton->setText(QCoreApplication::translate("TagPropertiesDialog", "&Add", nullptr));
        deleteAttrButton->setText(QCoreApplication::translate("TagPropertiesDialog", "&Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(attributesTab), QCoreApplication::translate("TagPropertiesDialog", "Attributes", nullptr));
        deleteRIDButton->setText(QCoreApplication::translate("TagPropertiesDialog", "&Remove", nullptr));
        addRIDButton->setText(QCoreApplication::translate("TagPropertiesDialog", "&Add", nullptr));
        label_5->setText(QCoreApplication::translate("TagPropertiesDialog", "Do not even think about changing anything in here!", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(remoteIDsTab), QCoreApplication::translate("TagPropertiesDialog", "Remote Identifiers", nullptr));
        (void)TagPropertiesDialog;
    } // retranslateUi

};

namespace Ui {
    class TagPropertiesDialog: public Ui_TagPropertiesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TAGPROPERTIESDIALOG_H
