/********************************************************************************
** Form generated from reading UI file 'collectionattributespage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLECTIONATTRIBUTESPAGE_H
#define UI_COLLECTIONATTRIBUTESPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CollectionAttributesPage
{
public:
    QGridLayout *gridLayout;
    QTreeView *attrView;
    QLineEdit *attrName;
    QPushButton *addButton;
    QPushButton *deleteButton;

    void setupUi(QWidget *CollectionAttributesPage)
    {
        if (CollectionAttributesPage->objectName().isEmpty())
            CollectionAttributesPage->setObjectName("CollectionAttributesPage");
        CollectionAttributesPage->resize(400, 300);
        gridLayout = new QGridLayout(CollectionAttributesPage);
        gridLayout->setObjectName("gridLayout");
        attrView = new QTreeView(CollectionAttributesPage);
        attrView->setObjectName("attrView");
        attrView->setRootIsDecorated(false);

        gridLayout->addWidget(attrView, 0, 0, 1, 3);

        attrName = new QLineEdit(CollectionAttributesPage);
        attrName->setObjectName("attrName");

        gridLayout->addWidget(attrName, 1, 0, 1, 1);

        addButton = new QPushButton(CollectionAttributesPage);
        addButton->setObjectName("addButton");

        gridLayout->addWidget(addButton, 1, 1, 1, 1);

        deleteButton = new QPushButton(CollectionAttributesPage);
        deleteButton->setObjectName("deleteButton");
        deleteButton->setEnabled(true);

        gridLayout->addWidget(deleteButton, 1, 2, 1, 1);


        retranslateUi(CollectionAttributesPage);

        QMetaObject::connectSlotsByName(CollectionAttributesPage);
    } // setupUi

    void retranslateUi(QWidget *CollectionAttributesPage)
    {
        attrName->setPlaceholderText(QCoreApplication::translate("CollectionAttributesPage", "New Attribute", nullptr));
        addButton->setText(QCoreApplication::translate("CollectionAttributesPage", "&Add", nullptr));
        deleteButton->setText(QCoreApplication::translate("CollectionAttributesPage", "&Delete", nullptr));
        (void)CollectionAttributesPage;
    } // retranslateUi

};

namespace Ui {
    class CollectionAttributesPage: public Ui_CollectionAttributesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLLECTIONATTRIBUTESPAGE_H
