/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.StorageDebugger.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef STORAGEDEBUGGERINTERFACE_H
#define STORAGEDEBUGGERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "querydebugger.h"

/*
 * Proxy class for interface org.freedesktop.Akonadi.StorageDebugger
 */
class OrgFreedesktopAkonadiStorageDebuggerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.StorageDebugger"; }

public:
    OrgFreedesktopAkonadiStorageDebuggerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiStorageDebuggerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QList<DbConnection> > connections()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("connections"), argumentList);
    }

    inline QDBusPendingReply<> enableSQLDebugging(bool enable)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(enable);
        return asyncCallWithArgumentList(QStringLiteral("enableSQLDebugging"), argumentList);
    }

    inline QDBusPendingReply<bool> isSQLDebuggingEnabled()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isSQLDebuggingEnabled"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void connectionChanged(qlonglong id, const QString &name);
    void connectionClosed(qlonglong id, qlonglong timestamp);
    void connectionOpened(qlonglong id, const QString &name, qlonglong timestamp);
    void queryExecuted(double sequence, qlonglong connectionId, qlonglong timestamp, uint duration, const QString &query, const QMap<QString,QVariant> & values, int resultsCount, const QList<QList<QVariant> > & result, const QString &error);
    void transactionFinished(qlonglong connectionId, bool commit, qlonglong timestamp, uint duration, const QString &error);
    void transactionStarted(qlonglong connectionId, const QString &name, qlonglong timestamp, uint duration, const QString &error);
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      using StorageDebugger = ::OrgFreedesktopAkonadiStorageDebuggerInterface;
    }
  }
}

#endif
