/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.akonadiconsole.logger.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef LOGGERADAPTOR_H
#define LOGGERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "logging.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.akonadiconsole.logger
 */
class LoggerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.akonadiconsole.logger")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.akonadiconsole.logger\">\n"
"    <method name=\"enabled\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"    </method>\n"
"    <signal name=\"enabledChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"    </signal>\n"
"    <method name=\"message\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"timestamp\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"app\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"pid\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"type\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"category\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"function\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"line\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"version\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"msg\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    LoggerAdaptor(Logging *parent);
    ~LoggerAdaptor() override;

    inline Logging *parent() const
    { return static_cast<Logging *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool enabled();
    void message(qlonglong timestamp, const QString &app, qlonglong pid, int type, const QString &category, const QString &file, const QString &function, int line, int version, const QString &msg);
Q_SIGNALS: // SIGNALS
    void enabledChanged(bool enabled);
};

#endif
