/********************************************************************************
** Form generated from reading UI file 'collectionaclpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLECTIONACLPAGE_H
#define UI_COLLECTIONACLPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CollectionAclPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *createItem;
    QCheckBox *changeItem;
    QCheckBox *deleteItem;
    QCheckBox *linkItem;
    QCheckBox *unlinkItem;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *createCollection;
    QCheckBox *changeCollection;
    QCheckBox *deleteCollection;
    QLabel *label;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CollectionAclPage)
    {
        if (CollectionAclPage->objectName().isEmpty())
            CollectionAclPage->setObjectName("CollectionAclPage");
        CollectionAclPage->resize(414, 411);
        verticalLayout = new QVBoxLayout(CollectionAclPage);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(CollectionAclPage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        createItem = new QCheckBox(groupBox);
        createItem->setObjectName("createItem");

        gridLayout->addWidget(createItem, 0, 0, 1, 1);

        changeItem = new QCheckBox(groupBox);
        changeItem->setObjectName("changeItem");

        gridLayout->addWidget(changeItem, 0, 1, 1, 1);

        deleteItem = new QCheckBox(groupBox);
        deleteItem->setObjectName("deleteItem");

        gridLayout->addWidget(deleteItem, 0, 2, 1, 1);

        linkItem = new QCheckBox(groupBox);
        linkItem->setObjectName("linkItem");

        gridLayout->addWidget(linkItem, 1, 0, 1, 1);

        unlinkItem = new QCheckBox(groupBox);
        unlinkItem->setObjectName("unlinkItem");

        gridLayout->addWidget(unlinkItem, 1, 2, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(CollectionAclPage);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        createCollection = new QCheckBox(groupBox_2);
        createCollection->setObjectName("createCollection");

        horizontalLayout_2->addWidget(createCollection);

        changeCollection = new QCheckBox(groupBox_2);
        changeCollection->setObjectName("changeCollection");

        horizontalLayout_2->addWidget(changeCollection);

        deleteCollection = new QCheckBox(groupBox_2);
        deleteCollection->setObjectName("deleteCollection");

        horizontalLayout_2->addWidget(deleteCollection);


        verticalLayout->addWidget(groupBox_2);

        label = new QLabel(CollectionAclPage);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        verticalSpacer = new QSpacerItem(20, 210, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(CollectionAclPage);

        QMetaObject::connectSlotsByName(CollectionAclPage);
    } // setupUi

    void retranslateUi(QWidget *CollectionAclPage)
    {
        groupBox->setTitle(QCoreApplication::translate("CollectionAclPage", "Item Access Rights", nullptr));
        createItem->setText(QCoreApplication::translate("CollectionAclPage", "Create", nullptr));
        changeItem->setText(QCoreApplication::translate("CollectionAclPage", "Modify", nullptr));
        deleteItem->setText(QCoreApplication::translate("CollectionAclPage", "Delete", nullptr));
        linkItem->setText(QCoreApplication::translate("CollectionAclPage", "Link", nullptr));
        unlinkItem->setText(QCoreApplication::translate("CollectionAclPage", "Unlink", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("CollectionAclPage", "Collection Access Rights", nullptr));
        createCollection->setText(QCoreApplication::translate("CollectionAclPage", "Create", nullptr));
        changeCollection->setText(QCoreApplication::translate("CollectionAclPage", "Modify", nullptr));
        deleteCollection->setText(QCoreApplication::translate("CollectionAclPage", "Delete", nullptr));
        label->setText(QCoreApplication::translate("CollectionAclPage", "<b>Note: </b>These values are provided by the corresponding backend and are not intended to be changed by you, so be warned if something breaks when changing them nevertheless!", nullptr));
        (void)CollectionAclPage;
    } // retranslateUi

};

namespace Ui {
    class CollectionAclPage: public Ui_CollectionAclPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLLECTIONACLPAGE_H
