/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.12.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // akonadiconsoleui.rc
  0x0,0x0,0x2,0xd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x28,0xc,0x1d,0x10,0x0,0x46,0x53,0x3a,0x1e,0x40,0x6f,0x1d,
  0x33,0xab,0x14,0xa0,0x94,0x1,0xda,0x58,0x4c,0x31,0x7f,0x40,0x91,0x14,0x50,0x9b,
  0x11,0x9f,0x20,0xc0,0x58,0xf9,0x38,0x7a,0xb0,0x73,0x1,0x35,0x0,0x30,0x0,0x2f,
  0x0,0x90,0x1b,0x8f,0x6a,0x1a,0x48,0x29,0xbb,0x96,0xb0,0x59,0x8b,0x16,0xb6,0x65,
  0xd5,0xc0,0x6f,0xa1,0x52,0x82,0x1a,0x60,0x37,0xe9,0x3c,0x3d,0xd,0xa4,0xd1,0x47,
  0x82,0xf7,0x8d,0x16,0x55,0x8d,0x45,0x4,0x22,0x81,0xa8,0x36,0x25,0xb5,0x78,0x48,
  0x22,0x9,0x87,0x2,0xf0,0x4,0xde,0xbf,0xbe,0x91,0x21,0xbf,0xec,0x6c,0x39,0x4f,
  0xa2,0x10,0xdf,0x6,0xa0,0xc7,0xf0,0x3f,0x90,0xb2,0x73,0xcd,0x1c,0x47,0x59,0x72,
  0x7e,0x2b,0x82,0x1c,0xe3,0x2a,0xe5,0x97,0x1b,0x17,0xec,0xf6,0xec,0xa0,0xdf,0x22,
  0x56,0xd,0xe4,0x8b,0x98,0x1,0x91,0x52,0x19,0x9b,0x33,0x39,0x99,0x72,0xb9,0x65,
  0xed,0x16,0x4b,0xb,0xf7,0x4d,0x4d,0xfa,0x64,0xec,0x4b,0x19,0xcc,0xc8,0x9,0xf9,
  0xe9,0x4f,0xcd,0xc4,0x66,0xaf,0x7d,0xea,0xc7,0xae,0x92,0xbf,0x79,0x4f,0x4b,0x59,
  0xfd,0x2b,0x8a,0xd6,0x9,0xd,0xd4,0xa6,0xe4,0x3c,0xbe,0xec,0x98,0x7b,0x98,0xc1,
  0x85,0xdb,0xd4,0xf8,0x94,0x1a,0x5,0x36,0x63,0x8f,0xed,0xfb,0x72,0x41,0x9c,0x27,
  0x67,0x99,0x71,0xb0,0x17,0x57,0xd8,0xfe,0x7c,0xfc,0x8c,0xc7,0xdf,0x24,0xb7,0x77,
  0x8e,0xed,0x91,0x1d,0x7,0x72,0xa0,0x71,0xe,0x8d,0xd1,0x84,0x49,0x51,0xa1,0x30,
  0xcc,0x1,0x20,0x46,0x40,0x90,0x62,0x43,0xe6,0x1,0x5d,0xe1,0x3,0x29,0x6d,0x18,
  0x27,0x3d,0xba,0x9b,0x3a,0x47,0x9,0xa4,0x7c,0x35,0x31,0xd9,0xec,0x9c,0x85,0x49,
  0x1a,0xdc,0x50,0x4d,0x81,0x64,0x66,0x81,0x94,0xe1,0x76,0xc0,0xa8,0x38,0x2e,0xea,
  0xbb,0xc4,0x6a,0x67,0x73,0xc7,0xd3,0xbf,0x4c,0x44,0x42,0xe4,0xd2,0xbd,0x11,0xc2,
  0x7c,0x32,0xac,0xce,0x97,0xc9,0xc9,0x3a,0x68,0xc8,0xb0,0xd,0xe3,0x96,0x16,0xfd,
  0x25,0x45,0xc5,0x54,0xd3,0x4c,0x38,0x93,0x32,0xb7,0x26,0x91,0x1a,0x90,0xc4,0xd6,
  0xd6,0xcb,0xb7,0xcb,0x0,0x6,0x16,0x83,0xba,0xb4,0x7,0x38,0x26,0xb4,0xc9,0x5a,
  0x77,0xab,0xc8,0x7f,0xe7,0x95,0xbd,0x5a,0x1c,0xc6,0x75,0x12,0xb3,0x87,0x58,0xaf,
  0xfe,0x81,0xaa,0x51,0x6c,0x42,0x4b,0x77,0x8,0x2a,0xbf,0x21,0x37,0x43,0x52,0x7c,
  0xb0,0x15,0x83,0x74,0x42,0xf2,0x29,0xca,0xc2,0x9c,0x1d,0xe8,0xac,0x80,0x46,0xea,
  0xd8,0xf0,0x83,0x13,0x1c,0xa,0xee,0x89,0xa4,0xbe,0x55,0x2d,0x77,0x6a,0xa6,0xe,
  0x28,0x67,0x18,0x4f,0x21,0x94,0x8a,0x63,0xbf,0xfc,0xca,0xfa,0x2b,0xb6,0x99,0xe0,
  0x9b,0xbe,0x9e,0x28,0xa0,0xf7,0x81,0xc1,0x81,0x1d,0xb5,0x58,0xdc,0x4c,0x2,0x1a,
  0xf4,0xe1,0x91,0xc8,0xbb,0x47,0x0,0x48,0x67,0x42,0xd3,0x67,0x8d,0xf3,0x97,0x94,
  0x41,0x85,0xc,0xd7,0x1c,0xdb,0xa0,0x4d,0x0,0xb8,0x52,0x61,0x54,0x56,0xba,0x78,
  0xfd,0x86,0xc2,0x32,0x5a,0x95,0xd7,0x69,0x5c,0xd3,0x21,0x21,0x2d,0x57,0x81,0x21,
  0x83,0x87,0x73,0x18,0xef,0xd4,0x9f,0x0,0x9d,0x0,0xa5,0x6,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // akonadiconsole
  0x0,0xe,
  0xe,0xad,0x8d,0xc5,
  0x0,0x61,
  0x0,0x6b,0x0,0x6f,0x0,0x6e,0x0,0x61,0x0,0x64,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,0x6f,0x0,0x6c,0x0,0x65,
    // akonadiconsoleui.rc
  0x0,0x13,
  0xd,0x1e,0x34,0x23,
  0x0,0x61,
  0x0,0x6b,0x0,0x6f,0x0,0x6e,0x0,0x61,0x0,0x64,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,0x6f,0x0,0x6c,0x0,0x65,0x0,0x75,0x0,0x69,0x0,0x2e,
  0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0xb7,0xdf,0xb4,0x18,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0xb7,0xdf,0xb4,0x18,
  // :/kxmlgui5/akonadiconsole
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0xb7,0xdf,0xb4,0x18,
  // :/kxmlgui5/akonadiconsole/akonadiconsoleui.rc
  0x0,0x0,0x0,0x38,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0xb7,0xdf,0xb4,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_akonadiconsole)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_akonadiconsole)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_akonadiconsole)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_akonadiconsole)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_akonadiconsole)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_akonadiconsole)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
