/********************************************************************************
** Form generated from reading UI file 'browserwidget_itemview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BROWSERWIDGET_ITEMVIEW_H
#define UI_BROWSERWIDGET_ITEMVIEW_H

#include <Akonadi/EntityTreeView>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ItemViewWidget
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QLabel *label;
    KComboBox *modelBox;
    Akonadi::EntityTreeView *itemView;

    void setupUi(QWidget *ItemViewWidget)
    {
        if (ItemViewWidget->objectName().isEmpty())
            ItemViewWidget->setObjectName("ItemViewWidget");
        ItemViewWidget->resize(481, 322);
        gridLayout = new QGridLayout(ItemViewWidget);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 0, 1, 1);

        label = new QLabel(ItemViewWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 1, 1, 1);

        modelBox = new KComboBox(ItemViewWidget);
        modelBox->setObjectName("modelBox");

        gridLayout->addWidget(modelBox, 0, 2, 1, 1);

        itemView = new Akonadi::EntityTreeView(ItemViewWidget);
        itemView->setObjectName("itemView");
        itemView->setDragEnabled(true);
        itemView->setAlternatingRowColors(true);
        itemView->setRootIsDecorated(false);

        gridLayout->addWidget(itemView, 1, 0, 1, 3);

#if QT_CONFIG(shortcut)
        label->setBuddy(modelBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ItemViewWidget);

        QMetaObject::connectSlotsByName(ItemViewWidget);
    } // setupUi

    void retranslateUi(QWidget *ItemViewWidget)
    {
        label->setText(QCoreApplication::translate("ItemViewWidget", "Model:", "model name"));
        (void)ItemViewWidget;
    } // retranslateUi

};

namespace Ui {
    class ItemViewWidget: public Ui_ItemViewWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BROWSERWIDGET_ITEMVIEW_H
